summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaccountmanager.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/libkopete/kopeteaccountmanager.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopeteaccountmanager.h')
-rw-r--r--kopete/libkopete/kopeteaccountmanager.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/kopete/libkopete/kopeteaccountmanager.h b/kopete/libkopete/kopeteaccountmanager.h
index 75ebf667..cfca90d3 100644
--- a/kopete/libkopete/kopeteaccountmanager.h
+++ b/kopete/libkopete/kopeteaccountmanager.h
@@ -43,9 +43,10 @@ class OnlineStatus;
* @author Martijn Klingens <klingens@kde.org>
* @author Olivier Goffart <ogoffart@ tiscalinet.be>
*/
-class KOPETE_EXPORT AccountManager : public QObject
+class KOPETE_EXPORT AccountManager : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -139,10 +140,10 @@ public slots:
*
* @param category is one of the Kopete::OnlineStatusManager::Categories
* @param awayMessage is the new away message
- * @param flags is a bitmask of SetOnlineStatusFlag
+ * @param flags is a bittqmask of SetOnlineStatusFlag
*/
void setOnlineStatus( /*Kopete::OnlineStatusManager::Categories*/ uint category,
- const TQString& awayMessage = TQString::null, uint flags=0);
+ const TQString& awayMessage = TQString(), uint flags=0);
/**
* \brief Set all accounts to away at once.
@@ -152,7 +153,7 @@ public slots:
* @param awayReason is the away message that will be set.
* @param away decides whether the message is away/non-away
*/
- void setAwayAll( const TQString &awayReason = TQString::null, bool away=true );
+ void setAwayAll( const TQString &awayReason = TQString(), bool away=true );
/**
* \brief Connect or make available every account.
@@ -162,7 +163,7 @@ public slots:
* This is a slot, so you can connect directly to it from e.g. a KAction.
* @param awayReason is the away(status) message that will be set.
*/
- void setAvailableAll( const TQString &awayReason = TQString::null );
+ void setAvailableAll( const TQString &awayReason = TQString() );
/**
* \internal
@@ -195,11 +196,11 @@ signals:
* \brief An account has changed its onlinestatus
* Technically this monitors Account::myself() onlinestatus changes
* \param account Account which changed its onlinestatus
* \param oldStatus The online status before the change
* \param newStatus The new online status
*/
void accountOnlineStatusChanged(Kopete::Account *account,
- const Kopete::OnlineStatus &oldStatus, const Kopete::OnlineStatus &newStatus);
+ const Kopete::OnlineStatus &oldtqStatus, const Kopete::OnlineStatus &newtqStatus);
private:
/**
@@ -210,7 +211,7 @@ private:
private slots:
void slotPluginLoaded( Kopete::Plugin *plugin );
void slotAccountOnlineStatusChanged(Kopete::Contact *c,
- const Kopete::OnlineStatus &oldStatus, const Kopete::OnlineStatus &newStatus);
+ const Kopete::OnlineStatus &oldtqStatus, const Kopete::OnlineStatus &newtqStatus);
/**
* \internal
@@ -195,11 +196,11 @@ signals:
* Technically this monitors Account::myself() onlinestatus changes
* \param account Account which changed its onlinestatus
- * \param oldStatus The online status before the change
- * \param newStatus The new online status
+ * \param oldtqStatus The online status before the change
+ * \param newtqStatus The new online status
*/
void accountOnlineStatusChanged(Kopete::Account *account,